pilas.tareas.TareaCondicional

Package pilas :: Module tareas :: Class TareaCondicional |
[hide private]
[frames] | no frames]

# Class TareaCondicional

source code

    object --+
             |
         Tarea --+
                 |
                TareaCondicional

Representa una tarea similar a Tarea, pero que solo se ejecuta si El retorno de la función a ejecutar devuelve True.

Instance Methods | [hide private]
ejecutar(self) Ejecuta la tarea, y se detiene si no revuelve True. | source code
Inherited from `Tarea`: `__init__`, `eliminar`, `terminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### ejecutar(self) | source code
Ejecuta la tarea, y se detiene si no revuelve True. Overrides: Tarea.ejecutar